==> polls-v1.4.1.zip: polls/messages/es/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Nota:</strong> el resultado se oculta hasta que un moderador cierra la encuesta.',
    'Access denied!' => 'Acceso denegado!',
    'Add answer...' => 'Añadir respuesta...',
    'Again? ;Weary;' => '¿De nuevo? ;Cansado;',
    'Allows the user to create polls' => 'Permite al usuario crear encuestas.',
    'Allows to start polls.' => 'Permite iniciar encuestas.',
    'Anonymous' => 'Anónimos',
    'Anonymous Votes?' => '¿Votos Anónimos?',
    'Anonymous poll!' => 'Encuesta anónima!',
    'Answers' => 'Respuestas',
    'At least one answer is required' => 'Se requiere al menos una respuesta',
    'Cancel' => 'Cancelar',
    'Close Poll' => 'Terminar la encuesta',
    'Closed' => 'Cerrado',
    'Club A Steakhouse' => 'Restaurante especializado en cortes de carne',
    'Could not load poll!' => '¡No se pudo cargar la votación!',
    'Create poll' => 'Crear encuesta',
    'Description' => 'Descripción',
    'Display answers in random order?' => '¿Mostrar respuestas en orden aleatorio?',
    'Edit answer (empty answers will be removed)...' => 'Editar respuesta (las respuestas vacías se eliminarán) ...',
    'Edit your poll question...' => 'Editar la pregunta de la encuesta ...',
    'Hide results until poll is closed?' => '¿Ocultar resultados hasta que se cierre la encuesta?',
    'Invalid answer!' => '¡Respuesta no válida!',
    'Location of the next meeting' => 'Lugar de la próxima reunión',
    'Multiple answers per user' => 'Multiples respuestas por usuario',
    'Pisillo Italian Panini' => 'Pisillo Italian Panini',
    'Please specify at least {min} answers!' => '¡Por favor, especifica al menos {min} respuestas!',
    'Poll' => 'Pregunta',
    'Polls' => 'Votaciones',
    'Question' => 'Pregunta',
    'Reopen Poll' => 'Vuelva a abrir la encuesta',
    'Reset my vote' => 'Reiniciar mi voto',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Ahora mismo, estamos en las etapas de planificación para nuestra próxima reunión y nos gustaría saber de usted, a dónde te gustaría ir?',
    'Save' => 'Guardar',
    'To Daniel' => 'Para Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Los usuarios votaron por: <strong>{answer}</strong>',
    'Vote' => 'Votar',
    'Voting for multiple answers is disabled!' => '¡Votar múltiples respuestas esta deshabilitado!',
    'Whenever someone participates in a poll.' => 'Siempre que alguien participe en una encuesta.',
    'Why don\'t we go to Bemelmans Bar?' => '¿Por qué no vamos al Bar Bemelmans?',
    'You have insufficient permissions to perform that operation!' => '¡No tienes suficientes permisos para hacer esa operación!',
    'and {count} more vote for this.' => 'y {count} mas votaron por esto.',
    'votes' => 'votos',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} respondió la {question}.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/es/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Nota:</strong> el resultado se oculta hasta que un moderador cierra la encuesta.',
    'Access denied!' => 'Acceso denegado!',
    'Add answer...' => 'Añadir respuesta...',
    'Again? :weary:' => '¿De nuevo? ;Cansado;',
    'Allows the user to create polls' => 'Permite al usuario crear encuestas.',
    'Allows to start polls.' => 'Permite iniciar encuestas.',
    'Anonymous' => 'Anónimos',
    'Anonymous Votes?' => '¿Votos Anónimos?',
    'Anonymous poll!' => 'Encuesta anónima!',
    'Answers' => 'Respuestas',
    'At least one answer is required' => 'Se requiere al menos una respuesta',
    'Cancel' => 'Cancelar',
    'Close Poll' => 'Terminar la encuesta',
    'Closed' => 'Cerrado',
    'Club A Steakhouse' => 'Restaurante especializado en cortes de carne',
    'Could not load poll!' => '¡No se pudo cargar la votación!',
    'Create poll' => 'Crear encuesta',
    'Description' => 'Descripción',
    'Display answers in random order?' => '¿Mostrar respuestas en orden aleatorio?',
    'Edit answer (empty answers will be removed)...' => 'Editar respuesta (las respuestas vacías se eliminarán) ...',
    'Edit your poll question...' => 'Editar la pregunta de la encuesta ...',
    'Hide results until poll is closed?' => '¿Ocultar resultados hasta que se cierre la encuesta?',
    'Invalid answer!' => '¡Respuesta no válida!',
    'Location of the next meeting' => 'Lugar de la próxima reunión',
    'Multiple answers per user' => 'Multiples respuestas por usuario',
    'Pisillo Italian Panini' => 'Pisillo Italian Panini',
    'Please specify at least {min} answers!' => '¡Por favor, especifica al menos {min} respuestas!',
    'Poll' => 'Pregunta',
    'Polls' => 'Votaciones',
    'Question' => 'Pregunta',
    'Reopen Poll' => 'Vuelva a abrir la encuesta',
    'Reset my vote' => 'Reiniciar mi voto',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Ahora mismo, estamos en las etapas de planificación para nuestra próxima reunión y nos gustaría saber de usted, a dónde te gustaría ir?',
    'Save' => 'Guardar',
    'To Daniel' => 'Para Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Los usuarios votaron por: <strong>{answer}</strong>',
    'Vote' => 'Votar',
    'Voting for multiple answers is disabled!' => '¡Votar múltiples respuestas esta deshabilitado!',
    'Whenever someone participates in a poll.' => 'Siempre que alguien participe en una encuesta.',
    'Why don\'t we go to Bemelmans Bar?' => '¿Por qué no vamos al Bar Bemelmans?',
    'You have insufficient permissions to perform that operation!' => '¡No tienes suficientes permisos para hacer esa operación!',
    'and {count} more vote for this.' => 'y {count} mas votaron por esto.',
    'votes' => 'votos',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} respondió la {question}.',
    'Poll content ID' => '',
];
